import datetime
from typing import Any, Dict, List, Type, TypeVar, Union, cast

import attr
from dateutil.parser import isoparse

from ..models.erratum import Erratum
from ..models.tracker_meta_attr import TrackerMetaAttr
from ..models.tracker_type_enum import TrackerTypeEnum
from ..types import UNSET, Unset

T = TypeVar("T", bound="OsidbApiV1TrackersCreateResponse201")


@attr.s(auto_attribs=True)
class OsidbApiV1TrackersCreateResponse201:
    """ """

    uuid: str
    type: TrackerTypeEnum
    external_system_id: str
    status: str
    errata: List[Erratum]
    meta_attr: TrackerMetaAttr
    created_dt: datetime.datetime
    updated_dt: datetime.datetime
    affects: Union[Unset, List[str]] = UNSET
    resolution: Union[Unset, str] = UNSET
    dt: Union[Unset, datetime.datetime] = UNSET
    env: Union[Unset, str] = UNSET
    revision: Union[Unset, str] = UNSET
    version: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        uuid = self.uuid
        type: str = UNSET
        if not isinstance(self.type, Unset):

            type = TrackerTypeEnum(self.type).value

        external_system_id = self.external_system_id
        status = self.status
        errata: List[Dict[str, Any]] = UNSET
        if not isinstance(self.errata, Unset):
            errata = []
            for errata_item_data in self.errata:
                errata_item: Dict[str, Any] = UNSET
                if not isinstance(errata_item_data, Unset):
                    errata_item = errata_item_data.to_dict()

                errata.append(errata_item)

        meta_attr: Dict[str, Any] = UNSET
        if not isinstance(self.meta_attr, Unset):
            meta_attr = self.meta_attr.to_dict()

        created_dt: str = UNSET
        if not isinstance(self.created_dt, Unset):
            created_dt = self.created_dt.isoformat()

        updated_dt: str = UNSET
        if not isinstance(self.updated_dt, Unset):
            updated_dt = self.updated_dt.isoformat()

        affects: Union[Unset, List[str]] = UNSET
        if not isinstance(self.affects, Unset):
            affects = self.affects

        resolution = self.resolution
        dt: Union[Unset, str] = UNSET
        if not isinstance(self.dt, Unset):
            dt = self.dt.isoformat()

        env = self.env
        revision = self.revision
        version = self.version

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        if uuid is not UNSET:
            field_dict["uuid"] = uuid
        if type is not UNSET:
            field_dict["type"] = type
        if external_system_id is not UNSET:
            field_dict["external_system_id"] = external_system_id
        if status is not UNSET:
            field_dict["status"] = status
        if errata is not UNSET:
            field_dict["errata"] = errata
        if meta_attr is not UNSET:
            field_dict["meta_attr"] = meta_attr
        if created_dt is not UNSET:
            field_dict["created_dt"] = created_dt
        if updated_dt is not UNSET:
            field_dict["updated_dt"] = updated_dt
        if affects is not UNSET:
            field_dict["affects"] = affects
        if resolution is not UNSET:
            field_dict["resolution"] = resolution
        if dt is not UNSET:
            field_dict["dt"] = dt
        if env is not UNSET:
            field_dict["env"] = env
        if revision is not UNSET:
            field_dict["revision"] = revision
        if version is not UNSET:
            field_dict["version"] = version

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        uuid = d.pop("uuid", UNSET)

        _type = d.pop("type", UNSET)
        type: TrackerTypeEnum
        if isinstance(_type, Unset):
            type = UNSET
        else:
            type = TrackerTypeEnum(_type)

        external_system_id = d.pop("external_system_id", UNSET)

        status = d.pop("status", UNSET)

        errata = []
        _errata = d.pop("errata", UNSET)
        if _errata is UNSET:
            errata = UNSET
        else:
            for errata_item_data in _errata or []:
                _errata_item = errata_item_data
                errata_item: Erratum
                if isinstance(_errata_item, Unset):
                    errata_item = UNSET
                else:
                    errata_item = Erratum.from_dict(_errata_item)

                errata.append(errata_item)

        _meta_attr = d.pop("meta_attr", UNSET)
        meta_attr: TrackerMetaAttr
        if isinstance(_meta_attr, Unset):
            meta_attr = UNSET
        else:
            meta_attr = TrackerMetaAttr.from_dict(_meta_attr)

        _created_dt = d.pop("created_dt", UNSET)
        created_dt: datetime.datetime
        if isinstance(_created_dt, Unset):
            created_dt = UNSET
        else:
            created_dt = isoparse(_created_dt)

        _updated_dt = d.pop("updated_dt", UNSET)
        updated_dt: datetime.datetime
        if isinstance(_updated_dt, Unset):
            updated_dt = UNSET
        else:
            updated_dt = isoparse(_updated_dt)

        affects = cast(List[str], d.pop("affects", UNSET))

        resolution = d.pop("resolution", UNSET)

        _dt = d.pop("dt", UNSET)
        dt: Union[Unset, datetime.datetime]
        if isinstance(_dt, Unset):
            dt = UNSET
        else:
            dt = isoparse(_dt)

        env = d.pop("env", UNSET)

        revision = d.pop("revision", UNSET)

        version = d.pop("version", UNSET)

        osidb_api_v1_trackers_create_response_201 = cls(
            uuid=uuid,
            type=type,
            external_system_id=external_system_id,
            status=status,
            errata=errata,
            meta_attr=meta_attr,
            created_dt=created_dt,
            updated_dt=updated_dt,
            affects=affects,
            resolution=resolution,
            dt=dt,
            env=env,
            revision=revision,
            version=version,
        )

        osidb_api_v1_trackers_create_response_201.additional_properties = d
        return osidb_api_v1_trackers_create_response_201

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="FlawMetaAttr")


@attr.s(auto_attribs=True)
class FlawMetaAttr:
    """ """

    acknowledgments: Union[Unset, str] = UNSET
    acks_not_needed: Union[Unset, str] = UNSET
    affects: Union[Unset, str] = UNSET
    alias: Union[Unset, str] = UNSET
    bz_datascore: Union[Unset, str] = UNSET
    bz_id: Union[Unset, str] = UNSET
    checklists: Union[Unset, str] = UNSET
    classification: Union[Unset, str] = UNSET
    cvss2: Union[Unset, str] = UNSET
    cvss2_score: Union[Unset, str] = UNSET
    cvss2_vector: Union[Unset, str] = UNSET
    cvss3: Union[Unset, str] = UNSET
    cvss3_comment: Union[Unset, str] = UNSET
    cvss3_score: Union[Unset, str] = UNSET
    cvss3_vector: Union[Unset, str] = UNSET
    cwe: Union[Unset, str] = UNSET
    depends_on: Union[Unset, str] = UNSET
    impact: Union[Unset, str] = UNSET
    jira_trackers: Union[Unset, str] = UNSET
    mitigate: Union[Unset, str] = UNSET
    mitigation: Union[Unset, str] = UNSET
    prestage_eligible_date: Union[Unset, str] = UNSET
    public: Union[Unset, str] = UNSET
    references: Union[Unset, str] = UNSET
    related_cves: Union[Unset, str] = UNSET
    reported: Union[Unset, str] = UNSET
    source: Union[Unset, str] = UNSET
    statement: Union[Unset, str] = UNSET
    task_owner: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        acknowledgments = self.acknowledgments
        acks_not_needed = self.acks_not_needed
        affects = self.affects
        alias = self.alias
        bz_datascore = self.bz_datascore
        bz_id = self.bz_id
        checklists = self.checklists
        classification = self.classification
        cvss2 = self.cvss2
        cvss2_score = self.cvss2_score
        cvss2_vector = self.cvss2_vector
        cvss3 = self.cvss3
        cvss3_comment = self.cvss3_comment
        cvss3_score = self.cvss3_score
        cvss3_vector = self.cvss3_vector
        cwe = self.cwe
        depends_on = self.depends_on
        impact = self.impact
        jira_trackers = self.jira_trackers
        mitigate = self.mitigate
        mitigation = self.mitigation
        prestage_eligible_date = self.prestage_eligible_date
        public = self.public
        references = self.references
        related_cves = self.related_cves
        reported = self.reported
        source = self.source
        statement = self.statement
        task_owner = self.task_owner

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        if acknowledgments is not UNSET:
            field_dict["acknowledgments"] = acknowledgments
        if acks_not_needed is not UNSET:
            field_dict["acks_not_needed"] = acks_not_needed
        if affects is not UNSET:
            field_dict["affects"] = affects
        if alias is not UNSET:
            field_dict["alias"] = alias
        if bz_datascore is not UNSET:
            field_dict["bz_datascore"] = bz_datascore
        if bz_id is not UNSET:
            field_dict["bz_id"] = bz_id
        if checklists is not UNSET:
            field_dict["checklists"] = checklists
        if classification is not UNSET:
            field_dict["classification"] = classification
        if cvss2 is not UNSET:
            field_dict["cvss2"] = cvss2
        if cvss2_score is not UNSET:
            field_dict["cvss2_score"] = cvss2_score
        if cvss2_vector is not UNSET:
            field_dict["cvss2_vector"] = cvss2_vector
        if cvss3 is not UNSET:
            field_dict["cvss3"] = cvss3
        if cvss3_comment is not UNSET:
            field_dict["cvss3_comment"] = cvss3_comment
        if cvss3_score is not UNSET:
            field_dict["cvss3_score"] = cvss3_score
        if cvss3_vector is not UNSET:
            field_dict["cvss3_vector"] = cvss3_vector
        if cwe is not UNSET:
            field_dict["cwe"] = cwe
        if depends_on is not UNSET:
            field_dict["depends_on"] = depends_on
        if impact is not UNSET:
            field_dict["impact"] = impact
        if jira_trackers is not UNSET:
            field_dict["jira_trackers"] = jira_trackers
        if mitigate is not UNSET:
            field_dict["mitigate"] = mitigate
        if mitigation is not UNSET:
            field_dict["mitigation"] = mitigation
        if prestage_eligible_date is not UNSET:
            field_dict["prestage_eligible_date"] = prestage_eligible_date
        if public is not UNSET:
            field_dict["public"] = public
        if references is not UNSET:
            field_dict["references"] = references
        if related_cves is not UNSET:
            field_dict["related_cves"] = related_cves
        if reported is not UNSET:
            field_dict["reported"] = reported
        if source is not UNSET:
            field_dict["source"] = source
        if statement is not UNSET:
            field_dict["statement"] = statement
        if task_owner is not UNSET:
            field_dict["task_owner"] = task_owner

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        acknowledgments = d.pop("acknowledgments", UNSET)

        acks_not_needed = d.pop("acks_not_needed", UNSET)

        affects = d.pop("affects", UNSET)

        alias = d.pop("alias", UNSET)

        bz_datascore = d.pop("bz_datascore", UNSET)

        bz_id = d.pop("bz_id", UNSET)

        checklists = d.pop("checklists", UNSET)

        classification = d.pop("classification", UNSET)

        cvss2 = d.pop("cvss2", UNSET)

        cvss2_score = d.pop("cvss2_score", UNSET)

        cvss2_vector = d.pop("cvss2_vector", UNSET)

        cvss3 = d.pop("cvss3", UNSET)

        cvss3_comment = d.pop("cvss3_comment", UNSET)

        cvss3_score = d.pop("cvss3_score", UNSET)

        cvss3_vector = d.pop("cvss3_vector", UNSET)

        cwe = d.pop("cwe", UNSET)

        depends_on = d.pop("depends_on", UNSET)

        impact = d.pop("impact", UNSET)

        jira_trackers = d.pop("jira_trackers", UNSET)

        mitigate = d.pop("mitigate", UNSET)

        mitigation = d.pop("mitigation", UNSET)

        prestage_eligible_date = d.pop("prestage_eligible_date", UNSET)

        public = d.pop("public", UNSET)

        references = d.pop("references", UNSET)

        related_cves = d.pop("related_cves", UNSET)

        reported = d.pop("reported", UNSET)

        source = d.pop("source", UNSET)

        statement = d.pop("statement", UNSET)

        task_owner = d.pop("task_owner", UNSET)

        flaw_meta_attr = cls(
            acknowledgments=acknowledgments,
            acks_not_needed=acks_not_needed,
            affects=affects,
            alias=alias,
            bz_datascore=bz_datascore,
            bz_id=bz_id,
            checklists=checklists,
            classification=classification,
            cvss2=cvss2,
            cvss2_score=cvss2_score,
            cvss2_vector=cvss2_vector,
            cvss3=cvss3,
            cvss3_comment=cvss3_comment,
            cvss3_score=cvss3_score,
            cvss3_vector=cvss3_vector,
            cwe=cwe,
            depends_on=depends_on,
            impact=impact,
            jira_trackers=jira_trackers,
            mitigate=mitigate,
            mitigation=mitigation,
            prestage_eligible_date=prestage_eligible_date,
            public=public,
            references=references,
            related_cves=related_cves,
            reported=reported,
            source=source,
            statement=statement,
            task_owner=task_owner,
        )

        flaw_meta_attr.additional_properties = d
        return flaw_meta_attr

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



""" Contains all the data models used in inputs/outputs """

from .affect import Affect
from .affect_meta_attr import AffectMetaAttr
from .affect_resolution_enum import AffectResolutionEnum
from .affect_type_enum import AffectTypeEnum
from .affectedness_enum import AffectednessEnum
from .auth_token_create_response_200 import AuthTokenCreateResponse200
from .auth_token_refresh_create_response_200 import AuthTokenRefreshCreateResponse200
from .auth_token_retrieve_response_200 import AuthTokenRetrieveResponse200
from .auth_token_verify_create_response_200 import AuthTokenVerifyCreateResponse200
from .blank_enum import BlankEnum
from .collectors_api_v1_status_retrieve_response_200 import CollectorsApiV1StatusRetrieveResponse200
from .collectors_api_v1_status_retrieve_response_200_collectors_item import (
    CollectorsApiV1StatusRetrieveResponse200CollectorsItem,
)
from .collectors_api_v1_status_retrieve_response_200_collectors_item_data import (
    CollectorsApiV1StatusRetrieveResponse200CollectorsItemData,
)
from .collectors_api_v1_status_retrieve_response_200_collectors_item_error import (
    CollectorsApiV1StatusRetrieveResponse200CollectorsItemError,
)
from .collectors_api_v1_status_retrieve_response_200_collectors_item_state import (
    CollectorsApiV1StatusRetrieveResponse200CollectorsItemState,
)
from .collectors_healthy_retrieve_response_200 import CollectorsHealthyRetrieveResponse200
from .collectors_retrieve_response_200 import CollectorsRetrieveResponse200
from .comment import Comment
from .comment_meta_attr import CommentMetaAttr
from .comment_type_enum import CommentTypeEnum
from .cv_ev_5_package_versions import CVEv5PackageVersions
from .cv_ev_5_versions import CVEv5Versions
from .erratum import Erratum
from .exploits_api_v1_collect_update_response_200 import ExploitsApiV1CollectUpdateResponse200
from .exploits_api_v1_cve_map_retrieve_response_200 import ExploitsApiV1CveMapRetrieveResponse200
from .exploits_api_v1_status_retrieve_response_200 import ExploitsApiV1StatusRetrieveResponse200
from .flaw import Flaw
from .flaw_classification import FlawClassification
from .flaw_classification_state import FlawClassificationState
from .flaw_meta_attr import FlawMetaAttr
from .flaw_resolution_enum import FlawResolutionEnum
from .flaw_type_enum import FlawTypeEnum
from .impact_enum import ImpactEnum
from .meta import Meta
from .meta_meta_attr import MetaMetaAttr
from .meta_type_enum import MetaTypeEnum
from .mitigated_by_enum import MitigatedByEnum
from .osidb_api_v1_affects_create_response_201 import OsidbApiV1AffectsCreateResponse201
from .osidb_api_v1_affects_destroy_response_204 import OsidbApiV1AffectsDestroyResponse204
from .osidb_api_v1_affects_list_affectedness import OsidbApiV1AffectsListAffectedness
from .osidb_api_v1_affects_list_impact import OsidbApiV1AffectsListImpact
from .osidb_api_v1_affects_list_resolution import OsidbApiV1AffectsListResolution
from .osidb_api_v1_affects_list_response_200 import OsidbApiV1AffectsListResponse200
from .osidb_api_v1_affects_list_type import OsidbApiV1AffectsListType
from .osidb_api_v1_affects_retrieve_response_200 import OsidbApiV1AffectsRetrieveResponse200
from .osidb_api_v1_affects_update_response_200 import OsidbApiV1AffectsUpdateResponse200
from .osidb_api_v1_flaws_create_response_201 import OsidbApiV1FlawsCreateResponse201
from .osidb_api_v1_flaws_destroy_response_204 import OsidbApiV1FlawsDestroyResponse204
from .osidb_api_v1_flaws_list_impact import OsidbApiV1FlawsListImpact
from .osidb_api_v1_flaws_list_mitigated_by import OsidbApiV1FlawsListMitigatedBy
from .osidb_api_v1_flaws_list_resolution import OsidbApiV1FlawsListResolution
from .osidb_api_v1_flaws_list_response_200 import OsidbApiV1FlawsListResponse200
from .osidb_api_v1_flaws_list_source import OsidbApiV1FlawsListSource
from .osidb_api_v1_flaws_list_state import OsidbApiV1FlawsListState
from .osidb_api_v1_flaws_list_type import OsidbApiV1FlawsListType
from .osidb_api_v1_flaws_retrieve_response_200 import OsidbApiV1FlawsRetrieveResponse200
from .osidb_api_v1_flaws_update_response_200 import OsidbApiV1FlawsUpdateResponse200
from .osidb_api_v1_manifest_retrieve_response_200 import OsidbApiV1ManifestRetrieveResponse200
from .osidb_api_v1_schema_retrieve_format import OsidbApiV1SchemaRetrieveFormat
from .osidb_api_v1_schema_retrieve_lang import OsidbApiV1SchemaRetrieveLang
from .osidb_api_v1_schema_retrieve_response_200 import OsidbApiV1SchemaRetrieveResponse200
from .osidb_api_v1_status_retrieve_response_200 import OsidbApiV1StatusRetrieveResponse200
from .osidb_api_v1_status_retrieve_response_200_osidb_data import OsidbApiV1StatusRetrieveResponse200OsidbData
from .osidb_api_v1_status_retrieve_response_200_osidb_service import OsidbApiV1StatusRetrieveResponse200OsidbService
from .osidb_api_v1_trackers_create_response_201 import OsidbApiV1TrackersCreateResponse201
from .osidb_api_v1_trackers_destroy_response_204 import OsidbApiV1TrackersDestroyResponse204
from .osidb_api_v1_trackers_list_response_200 import OsidbApiV1TrackersListResponse200
from .osidb_api_v1_trackers_list_type import OsidbApiV1TrackersListType
from .osidb_api_v1_trackers_retrieve_response_200 import OsidbApiV1TrackersRetrieveResponse200
from .osidb_api_v1_trackers_update_response_200 import OsidbApiV1TrackersUpdateResponse200
from .osidb_healthy_retrieve_response_200 import OsidbHealthyRetrieveResponse200
from .osidb_whoami_retrieve_response_200 import OsidbWhoamiRetrieveResponse200
from .osidb_whoami_retrieve_response_200_profile import OsidbWhoamiRetrieveResponse200Profile
from .osim_api_v1_workflows_adjust_create_response_200 import OsimApiV1WorkflowsAdjustCreateResponse200
from .osim_api_v1_workflows_retrieve_2_response_200 import OsimApiV1WorkflowsRetrieve2Response200
from .osim_api_v1_workflows_retrieve_response_200 import OsimApiV1WorkflowsRetrieveResponse200
from .osim_healthy_retrieve_response_200 import OsimHealthyRetrieveResponse200
from .osim_retrieve_response_200 import OsimRetrieveResponse200
from .paginated_affect_list import PaginatedAffectList
from .paginated_flaw_list import PaginatedFlawList
from .paginated_tracker_list import PaginatedTrackerList
from .source_enum import SourceEnum
from .state_enum import StateEnum
from .status_enum import StatusEnum
from .token_obtain_pair import TokenObtainPair
from .token_refresh import TokenRefresh
from .token_verify import TokenVerify
from .tracker import Tracker
from .tracker_meta_attr import TrackerMetaAttr
from .tracker_type_enum import TrackerTypeEnum



from typing import Any, Dict, Optional, Union

import requests

from ...client import AuthenticatedClient
from ...models.osidb_api_v1_affects_list_affectedness import OsidbApiV1AffectsListAffectedness
from ...models.osidb_api_v1_affects_list_impact import OsidbApiV1AffectsListImpact
from ...models.osidb_api_v1_affects_list_resolution import OsidbApiV1AffectsListResolution
from ...models.osidb_api_v1_affects_list_response_200 import OsidbApiV1AffectsListResponse200
from ...models.osidb_api_v1_affects_list_type import OsidbApiV1AffectsListType
from ...types import UNSET, Response, Unset


def _get_kwargs(
    *,
    client: AuthenticatedClient,
    affectedness: Union[Unset, None, OsidbApiV1AffectsListAffectedness] = UNSET,
    flaw: Union[Unset, None, str] = UNSET,
    impact: Union[Unset, None, OsidbApiV1AffectsListImpact] = UNSET,
    limit: Union[Unset, None, int] = UNSET,
    offset: Union[Unset, None, int] = UNSET,
    ps_component: Union[Unset, None, str] = UNSET,
    ps_module: Union[Unset, None, str] = UNSET,
    resolution: Union[Unset, None, OsidbApiV1AffectsListResolution] = UNSET,
    type: Union[Unset, None, OsidbApiV1AffectsListType] = UNSET,
    uuid: Union[Unset, None, str] = UNSET,
) -> Dict[str, Any]:
    url = "{}/osidb/api/v1/affects".format(
        client.base_url,
    )

    headers: Dict[str, Any] = client.get_headers()

    json_affectedness: Union[Unset, None, str] = UNSET
    if not isinstance(affectedness, Unset):

        json_affectedness = OsidbApiV1AffectsListAffectedness(affectedness).value if affectedness else None

    json_impact: Union[Unset, None, str] = UNSET
    if not isinstance(impact, Unset):

        json_impact = OsidbApiV1AffectsListImpact(impact).value if impact else None

    json_resolution: Union[Unset, None, str] = UNSET
    if not isinstance(resolution, Unset):

        json_resolution = OsidbApiV1AffectsListResolution(resolution).value if resolution else None

    json_type: Union[Unset, None, str] = UNSET
    if not isinstance(type, Unset):

        json_type = OsidbApiV1AffectsListType(type).value if type else None

    params: Dict[str, Any] = {
        "affectedness": json_affectedness,
        "flaw": flaw,
        "impact": json_impact,
        "limit": limit,
        "offset": offset,
        "ps_component": ps_component,
        "ps_module": ps_module,
        "resolution": json_resolution,
        "type": json_type,
        "uuid": uuid,
    }
    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    return {
        "url": url,
        "headers": headers,
        "params": params,
    }


def _parse_response(*, response: requests.Response) -> Optional[OsidbApiV1AffectsListResponse200]:
    if response.status_code == 200:
        _response_200 = response.json()
        response_200: OsidbApiV1AffectsListResponse200
        if isinstance(_response_200, Unset):
            response_200 = UNSET
        else:
            response_200 = OsidbApiV1AffectsListResponse200.from_dict(_response_200)

        return response_200
    return None


def _build_response(*, response: requests.Response) -> Response[OsidbApiV1AffectsListResponse200]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    *,
    client: AuthenticatedClient,
    affectedness: Union[Unset, None, OsidbApiV1AffectsListAffectedness] = UNSET,
    flaw: Union[Unset, None, str] = UNSET,
    impact: Union[Unset, None, OsidbApiV1AffectsListImpact] = UNSET,
    limit: Union[Unset, None, int] = UNSET,
    offset: Union[Unset, None, int] = UNSET,
    ps_component: Union[Unset, None, str] = UNSET,
    ps_module: Union[Unset, None, str] = UNSET,
    resolution: Union[Unset, None, OsidbApiV1AffectsListResolution] = UNSET,
    type: Union[Unset, None, OsidbApiV1AffectsListType] = UNSET,
    uuid: Union[Unset, None, str] = UNSET,
) -> Response[OsidbApiV1AffectsListResponse200]:
    kwargs = _get_kwargs(
        client=client,
        affectedness=affectedness,
        flaw=flaw,
        impact=impact,
        limit=limit,
        offset=offset,
        ps_component=ps_component,
        ps_module=ps_module,
        resolution=resolution,
        type=type,
        uuid=uuid,
    )

    response = requests.get(
        verify=client.verify_ssl,
        auth=client.auth,
        timeout=client.timeout,
        **kwargs,
    )
    response.raise_for_status()

    return _build_response(response=response)


def sync(
    *,
    client: AuthenticatedClient,
    affectedness: Union[Unset, None, OsidbApiV1AffectsListAffectedness] = UNSET,
    flaw: Union[Unset, None, str] = UNSET,
    impact: Union[Unset, None, OsidbApiV1AffectsListImpact] = UNSET,
    limit: Union[Unset, None, int] = UNSET,
    offset: Union[Unset, None, int] = UNSET,
    ps_component: Union[Unset, None, str] = UNSET,
    ps_module: Union[Unset, None, str] = UNSET,
    resolution: Union[Unset, None, OsidbApiV1AffectsListResolution] = UNSET,
    type: Union[Unset, None, OsidbApiV1AffectsListType] = UNSET,
    uuid: Union[Unset, None, str] = UNSET,
) -> Optional[OsidbApiV1AffectsListResponse200]:
    """ """

    return sync_detailed(
        client=client,
        affectedness=affectedness,
        flaw=flaw,
        impact=impact,
        limit=limit,
        offset=offset,
        ps_component=ps_component,
        ps_module=ps_module,
        resolution=resolution,
        type=type,
        uuid=uuid,
    ).parsed
